<?php

namespace Litecms\Feature\Providers;

use Illuminate\Support\ServiceProvider;

class FeatureServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'feature');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'feature');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.feature', function ($app) {
            return $this->app->make('Litecms\Feature\Feature');
        });

                // Bind Features to repository
        $this->app->bind(
            'Litecms\Feature\Interfaces\FeaturesRepositoryInterface',
            \Litecms\Feature\Repositories\Eloquent\FeaturesRepository::class
        );

        $this->app->register(\Litecms\Feature\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Feature\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Feature\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.feature'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/feature.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/feature')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/feature')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
